Applies a 1D convolution over the input signal.
Arguments
- input
Input mlx array. Shape depends on dimensionality (see individual functions).
- weight
Weight array. Shape depends on dimensionality (see individual functions).
- stride
Stride of the convolution. Can be a scalar or vector (length depends on dimensionality). Default: 1 for 1D, c(1,1) for 2D, c(1,1,1) for 3D.
- padding
Amount of zero padding. Can be a scalar or vector (length depends on dimensionality). Default: 0 for 1D, c(0,0) for 2D, c(0,0,0) for 3D.
- dilation
Spacing between kernel elements. Can be a scalar or vector (length depends on dimensionality). Default: 1 for 1D, c(1,1) for 2D, c(1,1,1) for 3D.
- groups
Number of blocked connections from input to output channels. Default: 1.
Details
Input has shape (N, L, C_in) where N is batch size, L is sequence length,
and C_in is number of input channels. Weight has shape (C_out, kernel_size, C_in).