Sample from a truncated normal distribution on mlx arrays
Source:R/random.R
mlx_rand_truncated_normal.RdSample from a truncated normal distribution on mlx arrays
Usage
mlx_rand_truncated_normal(lower, upper, dim, dtype = c("float32", "float64"))Arguments
- lower
Lower bound of the truncated normal.
- upper
Upper bound of the truncated normal.
- dim
Integer vector specifying array dimensions (shape).
- dtype
Data type string. Supported types include:
Floating point:
"float32","float64"Integer:
"int8","int16","int32","int64","uint8","uint16","uint32","uint64"Other:
"bool","complex64"
Not all functions support all types. See individual function documentation.
Examples
samples <- mlx_rand_truncated_normal(-1, 1, c(5, 5))