Since version 0.4.0, Rmlx supports character names and dimnames. These work
much like base R: names(), rownames(), colnames(), dimnames() and
associated setters all work. Dimnames may be NULL as a whole, and any
individual dimension's names may be NULL.
Details
Dimnames can be convenient, but they also slow down operations by adding work
in base R (mlx can't store character strings). In particular, slowdowns
for subsetting can be considerable, maybe 5x or 6x slower. To maximize
performance, you can avoid names, or remove them with unname().